; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------

[Command] ;Two quarter circles forward + y
name = "nsk"
command = ~D, DF, F, D, DF, F, y
time = 30 

;-| Special Motions |------------------------------------------------------

[Command] ;Quarter circle forward + a
name = "skull_A"
command = ~D, DF, F, a

[Command] ;Quarter circle forward + b
name = "skull_B"
command = ~D, DF, F, b

[Command] ;Quarter circle forward + c
name = "skull_C"
command = ~D, DF, F, c

[Command] ;Quarter circle back + a
name = "skull2_a"
command = ~D, DB, B, a

[Command] ;Quarter circle back + b
name = "skull2_b"
command = ~D, DB, B, b

[Command] ;Quarter circle back + c
name = "skull2_c"
command = ~D, DB, B, c

[Command] ;Tap A rapidly
name = "5A"
command = /$F, a, a, a
time = 30

[Command] ;Tap B rapidly
name = "5B"
command = /$F, b, b, b
time = 30

[Command] ;Tap C rapidly
name = "5C"
command = /$F, c, c, c
time = 30

[Command] ;Tap D rapidly
name = "patada"
command = /$F, x, x, x
time = 30

[Command] ;SHO-RYU-KEN-Y
name = "SRKY"
command = ~F, D, DF, y
time = 20

[Command] ;kicks_a
name = "kicks_A"
command = ~F, DF, F, x
time = 40


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
Name = "TAVILLO"
command = /$D , y
time = 1

[Command]
name = "down_z"
command = /$D, z
time = 1

[Command] ;Tap A rapidly
name = "tam"
command = /$F, c
time = 30

[Command] ;Tap A rapidly
name = "tamtam"
command = /$B, c
time = 30

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================

[State -1, patada con giro]
type = ChangeState
value = 1700
trigger1 = command = "kicks_A"
triggerall = power < 1000
trigger1 = statetype = s
trigger1 = ctrl

[State -1, patada con giro]
type = ChangeState
value = 1710
trigger1 = command = "kicks_A"
triggerall = power > 1000
triggerall = power != 3000
trigger1 = statetype = s
trigger1 = ctrl

[State -1, patada con giro]
type = ChangeState
value = 1720
trigger1 = command = "kicks_A"
triggerall = power =  3000
trigger1 = statetype = s
trigger1 = ctrl

;-------------------------------------------------------------------
[State -1, multiple skull throw]
type = ChangeState
value = 2000
trigger1 = command = "nsk"
triggerall = power > 1000
trigger1 = statetype = s
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, skull throw]
type = ChangeState
value = 1011
trigger1 = command = "skull_A"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, skull throw]
type = ChangeState
value = 1010
trigger1 = command = "skull_B"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, skull throw]
type = ChangeState
value = 1012
trigger1 = command = "skull_C"
trigger1 = statetype = S
trigger1 = ctrl
;===========================================================================
[State -1, skull throw]
type = ChangeState
value = 1021
trigger1 = command = "skull2_a"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, skull throw]
type = ChangeState
value = 1020
trigger1 = command = "skull2_b"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, skull throw]
type = ChangeState
value = 1022
trigger1 = command = "skull2_c"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, spin a roony weak]
type = ChangeState
value = 1000
trigger1 = command = "5A"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, spin a roony medium]
type = ChangeState
value = 1050
trigger1 = command = "5B"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, spin a roony hard]
type = ChangeState
value = 1080
trigger1 = command = "5C"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, kicks]
type = ChangeState
value = 1002
trigger1 = command = "patada"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, bite]
type = ChangeState
value = 1500
trigger1 = command = "SRKY"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
[State -1, air fire]
type = ChangeState
value = 1200
trigger1 = command = "skull_A"
trigger1 = statetype = A
trigger1 = statetype != S
trigger1 = statetype != C
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, air fire]
type = ChangeState
value = 1201
trigger1 = command = "skull_B"
trigger1 = statetype = A
trigger1 = statetype != S
trigger1 = statetype != C
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, air fire]
type = ChangeState
value = 1202
trigger1 = command = "skull_C"
trigger1 = statetype = A
trigger1 = statetype != S
trigger1 = statetype != C
trigger1 = ctrl
;---------------------------------------------------------------------------
;===========================================================================
; Roll Fwd
;----------------
[State -1, Roll Fwd]
type = ChangeState
value = 6000
trigger1 = command = "holdfwd"
trigger1 = stateno = 5120 && time <= 2

; Roll Back
;------------------
[State -1, Roll Back]
type = ChangeState
value = 6010
trigger1 = command = "holdback"
trigger1 = stateno = 5120 && time <= 2
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------

;Stand Light Punch 

[State -1, 0]
type = ChangeState
value = 201
triggerall = p2bodydist X > 24
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = stateno != 201
trigger1 = stateno != 1700
trigger1 = ctrl = 1
;trigger1 = stateno != 52


;---------------------------------------------------------------------------
;Stand Light Punch Close

[State -1, 1]
type = ChangeState
value = 200
triggerall = p2bodydist X < 25 ;Near P2
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = stateno != 200
triggerall = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------

;stand medium Punch close
;p`
[State -1, 2]
type = ChangeState
value = 210
triggerall = p2bodydist X < 24 ;Near P2
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = stateno != 210
triggerall = stateno != 240
triggerall = stateno != 700
triggerall = stateno != 710
triggerall = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------

;stand medium Punch 
;p`
[State -1, Stand medium Punch]
type = ChangeState
value = 211
triggerall = p2bodydist X > 25 ;far P2
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = stateno != 211
triggerall = stateno != 100
triggerall = stateno != 101
triggerall = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------

;stand strong Punch 
[State -1, Stand strong Punch ]
type = ChangeState
value = 221
triggerall = p2bodydist X > 24 ;far P2
triggerall = command = "c"
;triggerall = command != "holddown"
triggerall = stateno != 221
triggerall = stateno != 100
triggerall = stateno != 101
triggerall = stateno != 210
triggerall = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;stand strong Punch close
[State -1, Stand strong Punch close ]
type = ChangeState
value = 220
triggerall = p2bodydist X < 25 ;near P2
triggerall = P2BodyDist X > 3
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = stateno != 700
triggerall = stateno != 710
triggerall = stateno != 220
triggerall = stateno != 240
triggerall = statetype = S
trigger1 = ctrl


;---------------------------------------------------------------------------

;stand kick
;p`
[State -1, Stand kick]
type = ChangeState
value = 230
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = stateno != 499
triggerall = stateno != 230
triggerall = stateno != 105
triggerall = stateno != 100
triggerall = stateno != 101
triggerall = stateno != 499
triggerall = statetype = S
trigger1 = stateno != 20
trigger1 = ctrl


;---------------------------------------------------------------------------

;WALKING kick
;p`
[State -1, Walking kick]
type = ChangeState
value = 231
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = stateno != 231
triggerall = stateno != 105
triggerall = stateno != 100
triggerall = stateno != 101
triggerall = stateno != 499
triggerall = stateno != 21
triggerall = stateno = 20
triggerall = stateno != 499
trigger1 = ctrl

;----------------------------------------------------------------------;stand headbutt close
[State -1, Stand headbutt ]
type = ChangeState
value = 240
triggerall = p2bodydist X < 25 ;near P2
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = stateno != 240
triggerall = statetype = S
trigger1 = ctrl

;---------------------------------------------------

;running medium Punch
[State -1, running medium Punch]
type = ChangeState
value = 212
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = stateno != 212
trigger1 = stateno = 100
trigger2 = stateno = 101
triggerall = ctrl = 1

;---------------------------------------------------------------------------

;running strong Punch
[State -1, running strong Punch]
type = ChangeState
value = 213
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = stateno != 213
trigger1 = stateno = 100
trigger2 = stateno = 101
triggerall = ctrl = 1

;---------------------------------------------------------------------------

;running KICK
[State -1, running strong Punch]
type = ChangeState
value = 499
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = stateno != 499
trigger1 = stateno = 100
trigger2 = stateno = 101
triggerall = ctrl = 1

;---------------------------------------------------------------------------

[State -1, Stand rib cut ]
type = ChangeState
value = 214
triggerall = p2bodydist X > 24 ;near P2
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = stateno != 214
triggerall = statetype = S
trigger1 = ctrl


;---------------------------------------------------------------------------

;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = stateno != 400
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------

;Crouching medium Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 401
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = stateno != 401
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching strong Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 402
triggerall = command = "c"
triggerall = command = "holddown"
triggerall = stateno != 402
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching kick
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 403
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = stateno != 403
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------

;sweep kick
[State -1, kick sweept]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = stateno != 410
triggerall = stateno != 600
trigger1 = statetype = c
trigger1 = ctrl = 1


;---------------------------------------------------------------------------


[State -1, ground deflect]
type = ChangeState
value = 500
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = stateno != 501
triggerall = stateno != 214
triggerall = stateno != 600
triggerall = stateno != 601
trigger1 = statetype = s
trigger1 = ctrl = 1
;---------------------------------------------------------------------------

[State -1, air deflect]
type = ChangeState
value = 510
triggerall = command = "z"
triggerall = statetype = a
trigger1 = statetype = a
trigger1 = ctrl = 1

;---------------------------------------------------------------------------

[State -1, crouch deflect]
type = ChangeState
value = 504
triggerall = command = "down_z"
triggerall = statetype = c
triggerall = stateno != 504
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
[State -1, Grab Fwd]
type = ChangeState
value = 700
triggerall = command = "tam"
triggerall = statetype != A
triggerall = stateno != 700
triggerall = stateno != 710
triggerall = stateno != 210
triggerall = P2BodyDist X <= 2
trigger1 = ctrl

;---------------------------------------------------------------------------
; 
[State -1, Grab back]
type = ChangeState
value = 710
triggerall = command = "tamtam"
triggerall = statetype != A
triggerall = P2BodyDist X <= 10
triggerall = stateno != 700
triggerall = stateno != 210
trigger1 = ctrl


;---------------------------------------------------------------------------

;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "a"
triggerall = stateno != 600
triggerall = stateno != 0
triggerall = stateno != 600
triggerall = stateno != 601
triggerall = stateno != 602
triggerall = stateno != 603
triggerall = stateno != 105
trigger1 = statetype = A
trigger1 = ctrl 
;trigger2 = statetime >= 7

;---------------------------------------------------------------------------
;Jump medium Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 601
triggerall = command = "b"
trigger1 = statetype = A
triggerall = stateno != 600
triggerall = stateno != 601
triggerall = stateno != 602
triggerall = stateno != 603
triggerall = stateno != 105
trigger1 = ctrl


;---------------------------------------------------------------------------
;Jump strong Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 602
triggerall = command = "c"
triggerall = stateno != 600
triggerall = stateno != 601
triggerall = stateno != 602
triggerall = stateno != 603
triggerall = stateno != 105
trigger1 = statetype = A
trigger1 = ctrl


;---------------------------------------------------------------------------

;Jump kick
[State -1, Jump kick]
type = ChangeState
value = 630
triggerall = command = "x"
triggerall = stateno != 231
triggerall = stateno != 105
triggerall = anim != 600
triggerall = anim != 601
trigger1 = statetype = A
trigger1 = ctrl